//
//  @file M5Stack_KRS_changeID.ino
//  @brief M5Stack_KRS_changeID
//  @author Kondo Kagaku Co.,Ltd.
//  @date 2020/2/28
//

#include <M5Stack.h>
#include <IcsHardSerialClass.h>

const byte EN_PIN = 2;
long BAUDRATE = 115200;
const int TIMEOUT = 1000;    //通信できてないか確認用にわざと遅めに設定

IcsHardSerialClass krs(&Serial2,EN_PIN,BAUDRATE,TIMEOUT);  //インスタンス＋ENピン(2番ピン)およびUARTの指定


void setup() {

  M5.begin();   //M5Stack初期化
  M5.Power.begin();
 
  krs.begin();  //サーボモータの通信初期設定

  //LCD設定
  M5.Lcd.fillScreen(BLACK);
  M5.Lcd.setTextSize(3);
  M5.Lcd.setCursor(0, 0);
  M5.Lcd.print("NOW-ID:");
  M5.Lcd.setCursor(0, 25);
  M5.Lcd.print("Set-ID:");
  delay(1000);

  //ID番号を取得し表示する
  int id = krs.getID();
  M5.Lcd.setCursor(140, 0);
  M5.Lcd.print(id);

  //"Set-ID"の番号に0を表示
  M5.Lcd.setCursor(140, 25);
  M5.Lcd.print("0");

}

int BT_cnt = 0;

void loop()
{
  
  M5.update();        //ボタンの状態を確認

  //Aボタンが押されたとき（UP)
  if(M5.BtnA.wasPressed())
  {
    BT_cnt++;        //ボタンが押されるたびに1つ増える
    if(BT_cnt >= 32) //もし32以上になったら0にする
    {
      BT_cnt = 0;
    }
    
    M5.Lcd.setCursor(140, 25);  //カーソルを合わせる
    M5.Lcd.print("   ");        //一度表示を消す
    M5.Lcd.setCursor(140, 25);  //カーソルを合わせる
    M5.Lcd.print(BT_cnt);       //表示
  }

  //Bボタンが押されたとき（DOWN）
  if(M5.BtnB.wasPressed())
  {
    BT_cnt--;       //ボタンが押されるたびに1つ減らす
    if(BT_cnt <= -1)//もし-1になったら31にする
    {
      BT_cnt = 31;
    }

    M5.Lcd.setCursor(140, 25);  //カーソルを合わせる
    M5.Lcd.print("   ");        //一度表示を消す
    M5.Lcd.setCursor(140, 25);  //カーソルを合わせる
    M5.Lcd.print(BT_cnt);       //表示
  }

  //Cボタンが押されたとき（ENT）
  if(M5.BtnC.wasPressed())
  {
    int ID_check = 0;

    krs.setID(BT_cnt);    //ID番号書込み

    //ID番号が正しく書き込まれているか確認
    ID_check = krs.getID();    //ID番号読込
    M5.Lcd.setCursor(140, 0);  //カーソルをNOW-IDの行に合わせる
    M5.Lcd.print("   ");
    M5.Lcd.setCursor(140, 0);  //カーソルをNOW-IDの行に合わせる
    M5.Lcd.print(ID_check);    //ID番号表示
  }
}
